@@ -114,12 +114,15 @@ void app_open_location (const char *filename, Application *app) {
 
 typedef struct _OpenLocation {
     Application *app;
-    const char *filename;
+    char *filename;
+    gboolean fullscreen;
 } OpenLocation;
 
 static gboolean delayed_open_location (OpenLocation *ol) {
     app_open_location (ol->filename, ol->app);
     g_free (ol->filename);
+    if (ol->fullscreen)
+        app_full_screen (ol->app);
     free (ol);
     return FALSE;
 }
@@ -322,6 +325,9 @@ static void create_toolbar (Application * app) {
     gtk_list_store_set (model, &iterator, 0, "", -1);
     app->location_bar = gtk_combo_box_entry_new_with_model (
             GTK_TREE_MODEL (model), 0);
+    hildon_gtk_entry_set_input_mode (
+            GTK_ENTRY (gtk_bin_get_child (GTK_BIN (app->location_bar))),
+            HILDON_GTK_INPUT_MODE_FULL);
     app->progress_bar = hildon_seekbar_new ();
     /* Make combobox to use all available toolbar space */
     gtk_tool_item_set_expand (app->tb_location, TRUE);
@@ -520,7 +526,7 @@ gint dbus_req_handler( const gchar *interface, const gchar *method,
         for (i = 0; i < arguments->len; ++i) {
             osso_rpc_t val = g_array_index (arguments, osso_rpc_t, i);
             if (val.type == DBUS_TYPE_STRING && val.value.s != NULL) {
-                OpenLocation *ol = (OpenLocation *)malloc (sizeof (OpenLocation));
+                OpenLocation *ol = (OpenLocation *)g_malloc0 (sizeof (OpenLocation));
                 ol->filename = g_strdup(val.value.s);
                 ol->app = appdata;
                 g_idle_add (delayed_open_location, (gpointer)ol);
@@ -703,8 +709,14 @@ int main (int argc, char* argv[]) {
     g_object_ref (G_OBJECT (app->location_bar));
 
     if (argc > 1) {
-        OpenLocation *ol = (OpenLocation *)malloc (sizeof (OpenLocation));
-        ol->filename = g_strdup (argv[1]);
+        OpenLocation *ol = (OpenLocation *)g_malloc0 (sizeof (OpenLocation));
+        int i;
+        for (i = 1; i < argc; ++i) {
+            if (!strcmp (argv[i], "-fs"))
+                ol->fullscreen = 1;
+            else
+                ol->filename = g_strdup (argv[i]);
+        }
         ol->app = app;
         g_idle_add (delayed_open_location, (gpointer)ol);
     }
