@@ -23,7 +23,7 @@
 using namespace KMPlayer;
 
 static String getAsxAttribute (Element * e, const String & attr) {
-    for (AttributePtr a = e->attributes ()->first (); a; a = a->nextSibling ())
+    for (Attribute *a = e->attributes ()->first (); a; a = a->nextSibling ())
         if (attr == a->name ().toString ().lower ())
             return a->value ();
     return String ();
@@ -46,11 +46,11 @@ KMPLAYER_NO_EXPORT Node *ASX::Asx::childFromTag (const String & tag) {
 
 KDE_NO_EXPORT Node::PlayType ASX::Asx::playType () {
     if (cached_ismrl_version != document ()->m_tree_version)
-        for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
+        for (Node *e = firstChild (); e; e = e->nextSibling ()) {
             if (e->id == id_node_title)
-                caption = e->innerText ().stripWhiteSpace ();
+                title = e->innerText ().stripWhiteSpace ();
             else if (e->id == id_node_base)
-                src = getAsxAttribute (convertNode <Element> (e), "href");
+                src = getAsxAttribute (static_cast <Element *> (e), "href");
         }
     return Mrl::playType ();
 }
@@ -77,22 +77,22 @@ KMPLAYER_NO_EXPORT Node *ASX::Entry::childFromTag (const String & tag) {
 KDE_NO_EXPORT Node::PlayType ASX::Entry::playType () {
     if (cached_ismrl_version != document ()->m_tree_version) {
         ref_child_count = 0;
-        NodePtr ref;
-        for (NodePtr e = firstChild (); e; e = e->nextSibling ()) {
+        Node *ref = NULL;
+        for (Node *e = firstChild (); e; e = e->nextSibling ()) {
             switch (e->id) {
             case id_node_title:
-                caption = e->innerText ().stripWhiteSpace ();
+                title = e->innerText ().stripWhiteSpace ();
                 break;
             case id_node_base:
-                src = getAsxAttribute (convertNode <Element> (e), "href");
+                src = getAsxAttribute (static_cast <Element *> (e), "href");
                 break;
             case id_node_ref:
                 ref = e;
                 ref_child_count++;
             }
         }
-        if (ref_child_count == 1 && !caption.isEmpty ())
-            convertNode <ASX::Ref> (ref)->caption = caption;
+        if (ref_child_count == 1 && !title.isEmpty ())
+            static_cast <ASX::Ref *> (ref)->title = title;
         cached_ismrl_version = document()->m_tree_version;
     }
     return play_type_none;
@@ -100,16 +100,16 @@ KDE_NO_EXPORT Node::PlayType ASX::Entry::playType () {
 
 KMPLAYER_NO_EXPORT void ASX::Entry::activate () {
     resolved = true;
-    for (NodePtr e = firstChild (); e; e = e->nextSibling ())
+    for (Node *e = firstChild (); e; e = e->nextSibling ())
         if (e->id == id_node_param) {
-            Element * elm = convertNode <Element> (e);
+            Element *elm = static_cast <Element *> (e);
             if (getAsxAttribute(elm,"name").lower() == String("clipsummary")) {
                 String inf = URL::decode_string (
                                 getAsxAttribute (elm, "value"));
                 document ()->message (MsgInfoString, &inf);
             }
         } else if (e->id == id_node_duration) {
-            String s = convertNode <Element> (e)->getAttribute (
+            String s = static_cast <Element *> (e)->getAttribute (
                     StringPool::attr_value);
             int multiply[] = { 1, 60, 60 * 60, 24 * 60 * 60, 0 };
             int mpos = 0;
@@ -146,14 +146,14 @@ KMPLAYER_NO_EXPORT void ASX::Entry::deactivate () {
 }
 
 KMPLAYER_NO_EXPORT bool ASX::Entry::expose () const {
-    return ref_child_count > 1 && !caption.isEmpty ();
+    return ref_child_count > 1 && !title.isEmpty ();
 }
 
 //-----------------------------------------------------------------------------
 
 KMPLAYER_NO_EXPORT void ASX::Ref::opened () {
     src = getAsxAttribute (this, "href");
-    //kdDebug () << "Ref attr found src: " << src << endl;
+    Mrl::opened ();
 }
 
 KMPLAYER_NO_EXPORT bool ASX::Ref::expose () const {
@@ -164,6 +164,6 @@ KMPLAYER_NO_EXPORT bool ASX::Ref::expose () const {
 
 KMPLAYER_NO_EXPORT void ASX::EntryRef::opened () {
     src = getAsxAttribute (this, "href");
-    //kdDebug () << "EntryRef attr found src: " << src << endl;
+    Mrl::opened ();
 }
 
