@@ -45,7 +45,7 @@ public:
     KDE_NO_CDTOR_EXPORT Asx (NodePtr & d) : Mrl (d, id_node_asx) {}
     Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "ASX"; }
-    bool expose () const { return !caption.isEmpty (); }
+    bool expose () const { return !title.isEmpty (); }
     PlayType playType ();
 };
 
