@@ -68,7 +68,7 @@ void FileDocument::writeToFile (const String & fn) {
 KDE_NO_CDTOR_EXPORT Recents::Recents (Application *a)
     : FileDocument (id_node_recent_document, "recents://"),
       app(a) {
-    caption = "Most Recent";
+    title = "Most Recent";
 }
 
 KDE_NO_EXPORT void Recents::activate () {
@@ -123,8 +123,8 @@ KDE_NO_EXPORT void Recent::activate () {
 
 KDE_NO_CDTOR_EXPORT
 Group::Group (KMPlayer::NodePtr & doc, Application * a, const String & pn)
-  : KMPlayer::Element (doc, KMPlayer::id_node_group_node), app (a) {
-    caption = pn;
+  : KMPlayer::Title (doc, KMPlayer::id_node_group_node), app (a) {
+    title = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
 }
@@ -138,8 +138,8 @@ KDE_NO_EXPORT KMPlayer::Node *Group::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void Group::closed () {
-    if (caption.isEmpty ())
-        caption = getAttribute (KMPlayer::StringPool::attr_title);
+    if (title.isEmpty ())
+        title = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 // gconftool -s -t string /apps/maemo/kmplayer/playlist_file /home/koos/playlist.xml
@@ -163,7 +163,7 @@ KDE_NO_CDTOR_EXPORT Playlist::Playlist (Application *a, KMPlayer::Control *s, bo
     : FileDocument (KMPlayer::id_node_playlist_document, "Playlist://", s),
       app(a),
       playmode (plmode) {
-    caption = "Favorites";
+    title = "Favorites";
 }
 
 KDE_NO_EXPORT KMPlayer::Node *Playlist::childFromTag (const String & tag) {
@@ -203,23 +203,23 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
             data = String ("<playlist>") +
                 parentNode ()->innerXML () +
                 String ("</playlist>");
-            pn = parentNode ()->caption;
+            pn = parentNode ()->caption ();
         } else {
             data = outerXML ();
-            pn = caption.isEmpty () ? src : caption;
+            pn = title.isEmpty () ? src : title;
         }
-        pl->caption = pn;
+        pl->setCaption (pn);
         //debugLog () << "cloning to " << data << endl;
         TextStream inxml (data);
         KMPlayer::readXML (pl, inxml, String(), false);
         pl->normalize ();
-        NodePtr cur = pl->firstChild ();
+        Node *cur = pl->firstChild ();
         pl->mrl ()->resolved = !!cur;
         if (parentNode ()->id == KMPlayer::id_node_group_node && cur) {
-            KMPlayer::NodePtr sister = parentNode ()->firstChild ();
-            while (sister && cur && sister.ptr () != this) {
+            KMPlayer::Node *sister = parentNode ()->firstChild ();
+            while (sister && cur && sister != this) {
                 sister = sister->nextSibling ();
-            cur = cur->nextSibling ();
+                cur = cur->nextSibling ();
             }
         }
         CONTROL(app)->openDocument (pl, cur);
@@ -227,8 +227,8 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
 }
 
 KDE_NO_EXPORT void PlaylistItemBase::closed () {
-    if (caption.isEmpty ())
-        caption = getAttribute (KMPlayer::StringPool::attr_title);
+    if (title.isEmpty ())
+        title = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -251,24 +251,19 @@ KDE_NO_EXPORT void PlaylistItem::begin () {
         Mrl::begin ();
 }
 
-KDE_NO_EXPORT void PlaylistItem::setNodeName (const String & s) {
-    src = s;
-    setAttribute (KMPlayer::StringPool::attr_url, s);
-}
-
 KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, const String & pn)
- : KMPlayer::Element (doc, KMPlayer::id_node_group_node),
+ : KMPlayer::Title (doc, KMPlayer::id_node_group_node),
    app (a),
    playmode (false) {
-    caption = pn;
+    title = pn;
     if (!pn.isEmpty ())
         setAttribute (KMPlayer::StringPool::attr_title, pn);
 }
 
 KDE_NO_CDTOR_EXPORT
 PlaylistGroup::PlaylistGroup (KMPlayer::NodePtr & doc, Application * a, bool lm)
- : KMPlayer::Element (doc, KMPlayer::id_node_group_node),
+ : KMPlayer::Title (doc, KMPlayer::id_node_group_node),
    app (a),
    playmode (lm) {
 }
@@ -285,13 +280,8 @@ KDE_NO_EXPORT KMPlayer::Node *PlaylistGroup::childFromTag (const String & tag) {
 }
 
 KDE_NO_EXPORT void PlaylistGroup::closed () {
-    if (caption.isEmpty ())
-        caption = getAttribute (KMPlayer::StringPool::attr_title);
-}
-
-KDE_NO_EXPORT void PlaylistGroup::setNodeName (const String & t) {
-    caption = t;
-    setAttribute (KMPlayer::StringPool::attr_title, t);
+    if (title.isEmpty ())
+        title = getAttribute (KMPlayer::StringPool::attr_title);
 }
 
 KDE_NO_CDTOR_EXPORT
@@ -306,7 +296,7 @@ KDE_NO_EXPORT void HtmlObject::activate () {
 }
 
 KDE_NO_EXPORT void HtmlObject::closed () {
-    for (Node *n = firstChild ().ptr (); n; n = n->nextSibling ().ptr ()) {
+    for (Node *n = firstChild (); n; n = n->nextSibling ()) {
         if (n->id == KMPlayer::id_node_param) {
             KMPlayer::Element *e = static_cast <KMPlayer::Element *> (n);
             String name = e->getAttribute (KMPlayer::StringPool::attr_name);
