@@ -28,12 +28,12 @@ typedef struct _Application Application;
 
 namespace KMPlayer {
 
-static const short id_node_recent_document = 29;
-static const short id_node_recent_node = 30;
-static const short id_node_disk_document = 31;
-static const short id_node_disk_node = 32;
-static const short id_node_html_object = 33;
-static const short id_node_html_embed = 34;
+static const short id_node_recent_document = 30;
+static const short id_node_recent_node = 31;
+static const short id_node_disk_document = 32;
+static const short id_node_disk_node = 33;
+static const short id_node_html_object = 34;
+static const short id_node_html_embed = 35;
 
 class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
 public:
@@ -75,7 +75,7 @@ public:
     Application * app;
 };
 
-class KMPLAYER_NO_EXPORT Group : public KMPlayer::Element {
+class KMPLAYER_NO_EXPORT Group : public KMPlayer::Title {
 public:
     Group (KMPlayer::NodePtr &doc, Application *a, const String &pn=String());
     KMPlayer::Node *childFromTag (const String & tag);
@@ -111,17 +111,15 @@ public:
     PlaylistItem (KMPlayer::NodePtr & doc, Application *a, bool playmode, const String &url = String());
     void closed ();
     void begin ();
-    void setNodeName (const String &);
     KDE_NO_EXPORT const char * nodeName () const { return "item"; }
 };
 
-class KMPLAYER_NO_EXPORT PlaylistGroup : public KMPlayer::Element {
+class KMPLAYER_NO_EXPORT PlaylistGroup : public KMPlayer::Title {
 public:
     PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, const String &pn);
     PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, bool plmode=false);
     KMPlayer::Node *childFromTag (const String & tag);
     void closed ();
-    void setNodeName (const String &);
     KDE_NO_EXPORT const char * nodeName () const { return "group"; }
     Application * app;
     bool playmode;
