@@ -38,9 +38,9 @@ KDE_NO_CDTOR_EXPORT RP::Imfl::~Imfl () {
 }
 
 KDE_NO_EXPORT void RP::Imfl::closed () {
-    for (NodePtr n = firstChild (); n; n = n->nextSibling ())
+    for (Node *n = firstChild (); n; n = n->nextSibling ())
         if (RP::id_node_head == n->id) {
-            AttributePtr a = convertNode <Element> (n)->attributes ()->first ();
+            Attribute *a = convertNode <Element> (n)->attributes ()->first ();
             for (; a; a = a->nextSibling ()) {
                 if (StringPool::attr_width == a->name ()) {
                     width = a->value ().toInt ();
@@ -53,12 +53,13 @@ KDE_NO_EXPORT void RP::Imfl::closed () {
                 }
             }
         }
+    Mrl::closed ();
 }
 
 KDE_NO_EXPORT void RP::Imfl::defer () {
     debugLog () << "RP::Imfl::defer " << endl;
     setState (state_deferred);
-    for (Node * n = firstChild ().ptr (); n; n = n->nextSibling ().ptr ())
+    for (Node *n = firstChild (); n; n = n->nextSibling ())
         if (n->id == RP::id_node_image && !n->active ())
             n->activate ();
 }
@@ -129,7 +130,7 @@ KDE_NO_EXPORT void *RP::Imfl::message (MessageType msg, void *content) {
             return NULL;
         case MsgChildFinished:
             if (unfinished () && !duration_timer) {
-                for (NodePtr n = firstChild (); n; n = n->nextSibling ())
+                for (Node *n = firstChild (); n; n = n->nextSibling ())
                     switch (n->id) {
                         case RP::id_node_crossfade:
                         case RP::id_node_fadein:
@@ -204,6 +205,7 @@ KDE_NO_CDTOR_EXPORT RP::Image::~Image () {
 
 KDE_NO_EXPORT void RP::Image::closed () {
     src = getAttribute (StringPool::attr_name);
+    Mrl::closed ();
 }
 
 KDE_NO_EXPORT void RP::Image::activate () {
@@ -258,7 +260,7 @@ KDE_NO_EXPORT Surface *RP::Image::surface () {
     ImageActor *im = media_info && media_info->media
         ? (ImageActor *)media_info->media : NULL;
     if (im && !img_surface && !im->isEmpty ()) {
-        Node * p = parentNode ().ptr ();
+        Node *p = parentNode ();
         if (p && p->id == RP::id_node_imfl) {
             Surface *ps = static_cast <RP::Imfl *> (p)->surface ();
             if (ps)
@@ -277,12 +279,14 @@ KDE_NO_EXPORT void RP::TimingsBase::activate () {
     setState (state_activated);
     x = y = w = h = 0;
     srcx = srcy = srcw = srch = 0;
-    for (Attribute * a= attributes ()->first ().ptr (); a; a = a->nextSibling ().ptr ()) {
+    for (Attribute *a = attributes()->first (); a; a = a->nextSibling ()) {
         if (a->name () == StringPool::attr_target) {
-            for (NodePtr n = parentNode()->firstChild(); n; n= n->nextSibling())
-                if (convertNode <Element> (n)->
-                        getAttribute ("handle") == a->value ())
+            for (Node *n = parentNode()->firstChild(); n; n= n->nextSibling()) {
+                if (n->isElementNode () &&
+                        static_cast <Element *> (n)->
+                            getAttribute ("handle") == a->value ())
                     target = n;
+            }
         } else if (a->name () == "start") {
             int dur;
             parseTime (a->value ().lower (), dur);
@@ -367,7 +371,7 @@ KDE_NO_EXPORT void RP::TimingsBase::begin () {
 
 KDE_NO_EXPORT void RP::TimingsBase::update (int percentage) {
     progress = percentage;
-    Node * p = parentNode ().ptr ();
+    Node *p = parentNode ();
     if (p->id == RP::id_node_imfl)
         static_cast <RP::Imfl *> (p)->repaint ();
 }
@@ -499,14 +503,14 @@ KDE_NO_EXPORT void RP::ViewChange::activate () {
 KDE_NO_EXPORT void RP::ViewChange::begin () {
     //debugLog () << "RP::ViewChange::begin" << endl;
     setState (state_began);
-    Node * p = parentNode ().ptr ();
+    Node *p = parentNode ();
     if (p->id == RP::id_node_imfl)
         static_cast <RP::Imfl *> (p)->needs_scene_img++;
     update (0);
 }
 
 KDE_NO_EXPORT void RP::ViewChange::finish () {
-    Node * p = parentNode ().ptr ();
+    Node *p = parentNode ();
     if (p && p->id == RP::id_node_imfl)
         static_cast <RP::Imfl *> (p)->needs_scene_img--;
     TimingsBase::finish ();
