@@ -517,8 +517,11 @@ void Control::setTimeout (int ms) {
         : 0;
 }
 
-void Control::openUrl (const URL &, const String &, const String & /*srv*/) {
-    errorMsg ("Open for target and mimetype is not supported");
+void Control::openUrl (const URL &url, const String &, const String & /*srv*/) {
+    osso_rpc_run_with_defaults( m_app->osso_context, "osso_browser",
+            "open_new_window", NULL,
+            DBUS_TYPE_STRING, (const char *)url.url (), DBUS_TYPE_INVALID);
+    //errorMsg ("Open for target and mimetype is not supported");
 }
 
 void Control::addRepaintUpdater (Node *node) {
