@@ -150,7 +150,7 @@ void updatePlayTree (Application *app) MAEMO_NO_EXPORT;
 void rowSelected (Application *app) MAEMO_NO_EXPORT;
 void nextSelected (Application *app) MAEMO_NO_EXPORT;
 void previousSelected (Application *app) MAEMO_NO_EXPORT;
-short addTree (Application *a, KMPlayer::NodePtr doc, GdkPixbuf *ico) MAEMO_NO_EXPORT;
+short addTree (Application *a, KMPlayer::Mrl *doc, GdkPixbuf *ico) MAEMO_NO_EXPORT;
 void jump (KMPlayer::Node *n, Control *ctr) MAEMO_NO_EXPORT;
 
 } // namespace
