@@ -250,7 +250,7 @@ void Node::clearChildren () {
     m_first_child = m_last_child = 0L;
 }
 
-void Node::appendChild (NodePtr c) {
+void Node::appendChild (Node *c) {
     document()->m_tree_version++;
     ASSERT (!c->parentNode ());
     TreeNode<Node>::appendChild (c);
@@ -1334,7 +1334,7 @@ bool DocumentBuilder::startTag(const String &tag, AttributeListPtr attr) {
         if (m_node == n && m_node == m_root)
             m_root_is_first = true;
         else
-            m_node->appendChild (n);
+            m_node->appendChild (n.ptr ());
         if (m_set_opener && m_node == m_root) {
             Mrl * mrl = n->mrl ();
             if (mrl)
