@@ -167,7 +167,7 @@ public:
     virtual ~TreeNode () {}
 
     virtual void insertBefore (T *c, T *b);
-    virtual void appendChild (typename Item<T>::SharedType c);
+    virtual void appendChild (T *c);
     virtual void removeChild (typename Item<T>::SharedType c);
 
     bool hasChildNodes () const { return m_first_child != 0L; }
@@ -423,7 +423,7 @@ public:
     virtual void reset ();
     virtual void clear ();
     void clearChildren ();
-    void appendChild (NodePtr c);
+    void appendChild (Node *c);
     void insertBefore (Node *c, Node *b);
     void removeChild (NodePtr c);
     void replaceChild (NodePtr _new, NodePtr old);
@@ -938,9 +938,10 @@ inline T* List<T>::item (int i) const {
 }
 
 template <class T>
-inline void TreeNode<T>::appendChild (typename Item<T>::SharedType c) {
+inline void TreeNode<T>::appendChild (T *c) {
     if (!m_first_child) {
-        m_first_child = m_last_child = c;
+        m_first_child = c;
+        m_last_child = c;
     } else {
         m_last_child->m_next = c;
         c->m_prev = m_last_child;
@@ -952,7 +953,7 @@ inline void TreeNode<T>::appendChild (typename Item<T>::SharedType c) {
 template <class T>
 inline void TreeNode<T>::insertBefore (T *c, T *b) {
     if (!b) {
-        appendChild (c->m_self);
+        appendChild (c);
     } else {
         c->m_next = b->m_self;
         if (b->m_prev) {
