@@ -407,6 +407,7 @@ public:
     TextStreamTmpl <T> & operator << (const String & str);
     TextStreamTmpl <T> & operator << (const char * str);
     TextStreamTmpl <T> & operator << (const Char & ch);
+    TextStreamTmpl <T> & operator << (int i);
     TextStreamTmpl <T> & operator >> (Char & ch);
     TextStreamTmpl <T> & readRawBytes (char * b, unsigned length);
     TextStreamTmpl <T> & operator = (const TextStreamTmpl <T> & other);
@@ -1457,6 +1458,12 @@ inline TextStreamTmpl <T> & TextStreamTmpl <T>::operator << (const Char & ch) {
     return *this;
 }
 
+template <class T>
+inline TextStreamTmpl <T> & TextStreamTmpl <T>::operator << (int i) {
+    m_textstream << String::number (i);
+    return *this;
+}
+
 template <class T>
 inline TextStreamTmpl <T> & TextStreamTmpl <T>::operator >> (Char & ch) {
     m_textstream >> ch;
