@@ -43,6 +43,7 @@ public:
     Matrix (const Matrix & matrix);
     Matrix (Single xoff, Single yoff, float xscale, float yscale);
     void getXY (Single & x, Single & y) const;
+    void getWH (Single & w, Single & h) const;
     void getXYWH (Single & x, Single & y, Single & w, Single & h) const;
     void invXYWH (Single & x, Single & y, Single & w, Single & h) const;
     void transform (const Matrix & matrix);
@@ -60,7 +61,6 @@ public:
     void clear ();
     Surface *createSurface (NodePtr owner, const SRect & rect);
     IRect toScreen (Single x, Single y, Single w, Single h);
-    IRect clipToScreen (Single x, Single y, Single w, Single h);
     void resize (const SRect & rect, bool parent_resized=false);
     void repaint ();
     void repaint (const SRect &rect);
@@ -71,12 +71,16 @@ public:
     ViewArea *viewArea () { return view_widget; }
 
     NodePtrW node;
-    SRect bounds;                  // bounds in in parent coord.
+    SRect bounds;                  // bounds in parent coord.
+    SSize virtual_size;            // virtual size in screen coord.
     SSize size;                    // if set, dimension in Surface coord.
     float xscale, yscale;          // internal scaling
     unsigned int background_color; // rgba background color
+    unsigned short x_scroll;       // top of horizontal knob
+    unsigned short y_scroll;       // top of vertical knob
     cairo_surface_t *surface;
     bool dirty;                    // a decendant is removed
+    bool scroll;
 
 private:
     ViewArea *view_widget;
