@@ -1244,6 +1244,7 @@ public:
     void visit (SMIL::Layout *);
     void visit (SMIL::RegionBase *);
     void visit (SMIL::MediaType * n);
+    void visit (SMIL::SmilText * n);
     void visit (SMIL::Anchor *);
     void visit (SMIL::Area *);
 
@@ -1507,6 +1508,18 @@ KDE_NO_EXPORT void MouseVisitor::visit (SMIL::MediaType *mt) {
     }
 }
 
+KDE_NO_EXPORT void MouseVisitor::visit (SMIL::SmilText *st) {
+    if (MsgEventClicked == event) {
+        NodeRefList *nl = nodeMessageReceivers (st, event);
+        if (nl)
+            for (NodeRefItemPtr c = nl->first(); c; c = c->nextSibling ()) {
+                if (c->data && c->data.ptr () != st)
+                    c->data->accept (this);
+                if (!node->active ())
+                    return;
+            }
+    }
+}
 //-----------------------------------------------------------------------------
 
 namespace KMPlayer {
@@ -1903,12 +1916,19 @@ KDE_NO_EXPORT bool ViewArea::timeoutPaintEvent () {
 
 bool ViewArea::scheduleRepaintTimeout (unsigned int cur_time) {
     int timeout;
-    if (!cur_time)
+    if (!cur_time) {
         timeout = 20;
-    else if (last_repaint_time + penalty < cur_time)
-        timeout = 20;
-    else
-        timeout = 20 + penalty - (cur_time - last_repaint_time);
+    } else {
+        Document *doc = surface->node ? surface->node->document () : NULL;
+        if (doc && doc->last_event_time < last_repaint_time) {
+            last_repaint_time = doc->last_event_time;
+            penalty = 30;
+        }
+        if (last_repaint_time + penalty < cur_time)
+            timeout = 20;
+        else
+            timeout = 20 + penalty - (cur_time - last_repaint_time);
+    }
     next_repaint_time = cur_time + timeout;
     if (m_repaint_timer && abs (cur_timeout - timeout) < 5)
         return true;
@@ -2023,6 +2043,7 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
     ViewArea *view_area = VIEWAREA(a);
     static Time down_time;
     static int down_x;
+    static int down_y;
 
     if (view_area->controls &&
             event->xany.window == GDK_DRAWABLE_XID (view_area->controls))
@@ -2087,8 +2108,9 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
                     updatePlayTree (a);
                 view_area->controlsVisible (a, true);
             } else if (event->xany.window == w || event->xany.window == i) {
-                if (event->xbutton.time - down_time < 600 &&
-                        abs (down_x - event->xbutton.x) < 80 ) {
+                if (event->xbutton.time - down_time < 500 &&
+                        abs (down_x - event->xbutton.x) < 80 &&
+                        abs (down_y - event->xbutton.y) < 80) {
                     view_area->prepareFullscreenToggle ();
                     if (a->fullscreen)
                         app_normal_screen (a);
@@ -2098,6 +2120,7 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
                     return GDK_FILTER_REMOVE;
                 } else {
                     down_x = event->xbutton.x;
+                    down_y = event->xbutton.y;
                     down_time = event->xbutton.time;
                 }
             }
