@@ -59,6 +59,7 @@ public:
     bool timeoutPaintEvent ();
     void controlsVisible (Application *app, bool show);
     void prepareFullscreenToggle ();
+    void enableVideoInputFilter (bool enable);
     KDE_NO_EXPORT Rect videoGeometry () const { return m_av_geometry; }
     int width () const;
     int height () const;
@@ -93,6 +94,7 @@ private:
     bool m_event_filter_on;
     bool m_updaters_enabled;
     bool m_controls_overlap;
+    bool m_video_filter;
 };
 
 } // namespace KMPlayer
